/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.glassfish.auth;

import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.security.auth.login.LoginException;

import com.sun.enterprise.security.auth.login.PasswordLoginModule;

/**
 * Login module for the flexible JDBC realm. This login module must be
 * configured in glassfish.
 * 
 * @author Erik Brakkee
 */
public class FlexibleJdbcLoginModule extends PasswordLoginModule {

    private static final Logger LOGGER = Logger
        .getLogger(FlexibleJdbcLoginModule.class.getName());

    public FlexibleJdbcLoginModule() {
        // Empty
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.sun.appserv.security.AppservPasswordLoginModule#authenticateUser()
     */
    @Override
    protected void authenticate() throws LoginException {
        if (LOGGER.isLoggable(Level.FINEST)) {
            // NOTE: deliberately not logging the password.
            LOGGER.finest("CustomRealm Auth Info:_username:" + _username +
                ", currentrealm: " + _currentRealm);
        }

        // Get the current realm and check whether it is instance of your realm
        if (!(_currentRealm instanceof FlexibleJdbcRealm)) {
            throw new LoginException("_currentRealm is a bad realm");
        }
        FlexibleJdbcRealm customRealm = (FlexibleJdbcRealm) _currentRealm;

        if (_username == null || _username.length() == 0) {
            String msg = "Null user";
            throw new LoginException(msg);
        }

        String[] grpList = customRealm.authenticateUser(_username, _password);

        if (grpList == null) { // JAAS behavior
            throw new LoginException("customrealm:Login Failed with user  " +
                _username);
        }

        if (LOGGER.isLoggable(Level.FINEST)) {
            LOGGER.finest("login succeeded for  " + _username);
        }

        // Add the code related to authenticating to your user database.
        String[] groupListToForward = (String[]) grpList.clone();

        /*
         * Call the commitAuthentication to populate grpList with the set of
         * groups to which _username belongs in this realm.
         */
        /*
         * commitUserAuthentication(_username, _password, _currentRealm,
         * groupListToForward);
         */
        if (LOGGER.isLoggable(Level.FINEST)) {
            LOGGER.fine("Group list in login module " +
                Arrays.asList(groupListToForward));
        }
        commitUserAuthentication(groupListToForward);
    }
}
