/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.glassfish.auth;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

/**
 * A cache that caches forever.  
 * 
 * @author Erik Brakkee
 */
public class ForeverGroupCache implements GroupCache {
    
    private Map<String, List<String>> cache; 
    
    public ForeverGroupCache() { 
        cache = new TreeMap<String,List<String>>();
    }
    
    @Override
    public synchronized List<String> getGroups(String aUser) {
        return cache.get(aUser);
    }
    
    @Override
    public synchronized void setGroups(String aUser, List<String> aGroups) {
        if (aGroups == null) {
            aGroups = new ArrayList<String>();
        }
        cache.put(aUser, aGroups);       
    }

}
