/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.glassfish.auth;

import java.math.BigInteger;
import java.util.logging.Logger;

/**
 * Encoder of binary data into a hex representation. 
 * @author Erik Brakkee
 *
 */
public class HexEncoder implements Encoder {
    
    private static final Logger LOGGER = Logger.getLogger(HexEncoder.class.getName());
    
    public static final int PADDING_DEFAULT = 32; 
    private static final String ZEROES8 = "00000000";

    private int padding; 
    
    /**
     * Constructs encoder with default padding. 
     */
    public HexEncoder() { 
        padding = PADDING_DEFAULT;
    }
    
    /**
     * Constructs encoder with padding length. . 
     * @param aPadding Padding to use. 
     */
    public HexEncoder(int aPadding) { 
        padding = aPadding; 
    }
    
    @Override
    public String encode(byte[] aData) {
        String res = new BigInteger(1, aData).toString(16);
        if (res.length() > padding) {
            LOGGER.warning("Number larger than " + padding + " characters in hex");
            return res; 
        }
        StringBuffer padstr = new StringBuffer();
        int numpad = padding - res.length(); 
        while (numpad > 0) { 
            if ( numpad >= 8) { 
                padstr.append(ZEROES8);
                numpad -= 8;
            } else { 
                padstr.append("0");
                numpad--; 
            }
        }
        return padstr.toString() + res; 
    }
    
    
    public int getPadding() {
        return padding;
    }

}
